@@ -8,8 +8,10 @@
 DISCO SDK Library
 """
 
-# from .gql import authentication
 from .job import Job
 from .cluster import Cluster
-from .asset import upload_file, Asset
+from .asset import upload_file, input_files_from_bucket, Asset
 from .core.credentials import set_credentials
+from .repository import Repository
+from .docker_image import DockerImage
+from .core.config import Config
