@@ -254,11 +254,9 @@ class Job(BaseController):
           Returns:
               The status of the job.
         """
-        job_details = self.get_details()
-        if constants.JobStatus(job_details.status) == constants.JobStatus.done and \
-                job_details.tasks_summary.failed > 0:
-            return constants.JobStatus.failed
-        return constants.JobStatus(job_details.status)
+        response = self.query('fetchJobStatus', id=self.job_id)
+        raw_status = response['fetchJob']['status']
+        return constants.JobStatus(raw_status)
 
     def wait_for_finish(self, interval=5, timeout=TIMEOUT):
         """Wait for a job to finish.
