@@ -1,3 +1,4 @@
+from disco.core.constants import JobStatus
 from .base_model import BaseModel
 
 
@@ -20,7 +21,24 @@ class JobDetails(BaseModel):
         Returns:
             str
         """
-        return self._data.get('status')
+        cur_status = self._data.get('status')
+        return JobStatus.done.value if cur_status == JobStatus.stopped.value else cur_status
+
+    @property
+    def stopped(self):
+        """
+        Returns:
+            boolean
+        """
+        return self._data.get('status') == JobStatus.stopped.value
+
+    @property
+    def archived(self):
+        """
+        Returns:
+            str
+        """
+        return self._data.get('archived')
 
     @property
     def name(self):
@@ -49,13 +67,11 @@ class TasksSummary:  #pylint: disable=redefined-builtin,too-many-instance-attrib
     """
 
     # pylint: disable=too-many-arguments
-    def __init__(self, waiting=0, queued=0, running=0, failed=0, success=0, timeout=0, lost=0, unknown=0, all=0):
+    def __init__(self, queued=0, running=0, failed=0, success=0, stopped=0, timeout=0, all=0):
         self.queued = queued
         self.running = running
         self.failed = failed
         self.success = success
+        self.stopped = stopped
         self.timeout = timeout
-        self.waiting = waiting
-        self.lost = lost
-        self.unknown = unknown
         self.all = all
